==> cilint-0.0.2.tgz: package/lib/formatters/stylish.js <==
/**
 * @fileoverview Stylish reporter
 * @author Sindre Sorhus
 */
"use strict";

const chalk = require("chalk"),
    table = require("text-table");

//------------------------------------------------------------------------------
// Helpers
//------------------------------------------------------------------------------

/**
 * Given a word and a count, append an s if count is not one.
 * @param {string} word A word in its singular form.
 * @param {int} count A number controlling whether word should be pluralized.
 * @returns {string} The original word with an s on the end if count is not one.
 */
function pluralize(word, count) {
    return (count === 1 ? word : `${word}s`);
}

//------------------------------------------------------------------------------
// Public Interface
//------------------------------------------------------------------------------

module.exports = function(results) {

    let output = "\n",
        total = 0,
        errors = 0,
        warnings = 0,
        summaryColor = "yellow";

    results.forEach(result => {
        const messages = result.messages;

        if (messages.length === 0) {
            return;
        }

        total += messages.length;
        output += `${chalk.underline(result.filePath)}\n`;

        const rows = [];

        messages.forEach(message => {
            let messageType;

            if (message.fatal || message.severity === 2) {
                messageType = chalk.red("error");
                summaryColor = "red";
                errors++;
            } else {
                messageType = chalk.yellow("warning");
                warnings++;
            }

            rows.push([
                "",
                message.line || 0,
                message.column || 0,
                messageType,
                message.message.replace(/\.$/, ""),
                chalk.dim(message.ruleId || "")
            ]);
            rows.push([
                "",
                "",
                "",
                "",
                chalk.dim((message.source || '').split('\n')[0].trim()),
                ""
            ]);
        });

        output += `${table(
            rows,
            {
                align: ["", "r", "l"],
                stringLength(str) {
                    return chalk.stripColor(str).length;
                }
            }
        ).split("\n").map(el => el.replace(/(\d+)\s+(\d+)/, (m, p1, p2) => chalk.dim(`${p1}:${p2}`))).join("\n")}\n\n`;
    });

    if (total > 0) {
        output += chalk[summaryColor].bold([
            "\u2716 ", total, pluralize(" problem", total),
            " (", errors, pluralize(" error", errors), ", ",
            warnings, pluralize(" warning", warnings), ")\n"
        ].join(""));
    }

    return total > 0 ? output : "";
};

==> cilint-0.0.6.tgz: package/lib/formatters/stylish.js <==
/**
 * @fileoverview Stylish reporter
 * @author Sindre Sorhus
 */
"use strict";

const chalk = require("chalk"),
    table = require("text-table");

//------------------------------------------------------------------------------
// Helpers
//------------------------------------------------------------------------------

/**
 * Given a word and a count, append an s if count is not one.
 * @param {string} word A word in its singular form.
 * @param {int} count A number controlling whether word should be pluralized.
 * @returns {string} The original word with an s on the end if count is not one.
 */
function pluralize(word, count) {
    return (count === 1 ? word : `${word}s`);
}

//------------------------------------------------------------------------------
// Public Interface
//------------------------------------------------------------------------------

module.exports = function(results) {

    let output = "\n",
        total = 0,
        errors = 0,
        warnings = 0,
        summaryColor = "yellow";

    results.forEach(result => {
        const messages = result.messages;

        if (messages.length === 0) {
            return;
        }

        total += messages.length;
        output += `${chalk.underline(result.filePath)}\n`;

        const rows = [];

        messages.forEach(message => {
            let messageType;

            if (message.fatal || message.severity === 2) {
                messageType = chalk.red("error");
                summaryColor = "red";
                errors++;
            } else {
                messageType = chalk.yellow("warning");
                warnings++;
            }

            rows.push([
                "",
                message.line || 0,
                message.column || 0,
                messageType,
                message.message.replace(/\.$/, ""),
                chalk.dim(message.ruleId || "")
            ]);
            rows.push([
                "",
                "",
                "",
                "",
                chalk.dim((message.source || '').split('\n')[0].trim()),
                ""
            ]);
        });

        output += `${table(
            rows,
            {
                align: ["", "r", "l"],
                stringLength(str) {
                    return chalk.stripColor(str).length;
                }
            }
        ).split("\n").map(el => el.replace(/(\d+)\s+(\d+)/, (m, p1, p2) => chalk.dim(`${p1}:${p2}`))).join("\n")}\n\n`;
    });

    if (total > 0) {
        output += chalk[summaryColor].bold([
            "\u2716 ", 
            errors, pluralize(" error", errors), ", ",
            warnings, pluralize(" warning", warnings), 
            " (", 
            total, pluralize(" problem", total),
            ")\n"
        ].join(""));
    }

    return total > 0 ? output : "";
};
